==> mktcenter-service-threetree-1.0-20251016.090209-34-sources.jar: com/bizvane/mktcenterservice/models/vo/ProbabilityVO.java <==
package com.bizvane.mktcenterservice.models.vo;

/**
 * @Author: lijunwei
 * @Time: 2019/2/25 22:02
 */
public class ProbabilityVO {
    private Long mktActivityId;
    private String activityCode;
    private String memberCode;
    private Integer activityType;
    private Integer triesLimit;
    private Integer shareNum;
    private String organizationCode;
    //是否屏蔽总部 0不屏蔽,1屏蔽
    private int screenSysCompany;

    public Long getMktActivityId() {
        return mktActivityId;
    }

    public void setMktActivityId(Long mktActivityId) {
        this.mktActivityId = mktActivityId;
    }

    public String getActivityCode() {
        return activityCode;
    }

    public void setActivityCode(String activityCode) {
        this.activityCode = activityCode;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public Integer getTriesLimit() {
        return triesLimit;
    }

    public void setTriesLimit(Integer triesLimit) {
        this.triesLimit = triesLimit;
    }

    public Integer getActivityType() {
        return activityType;
    }

    public void setActivityType(Integer activityType) {
        this.activityType = activityType;
    }

    public Integer getShareNum() {
        return shareNum;
    }

    public void setShareNum(Integer shareNum) {
        this.shareNum = shareNum;
    }

    public String getOrganizationCode() {
        return organizationCode;
    }

    public void setOrganizationCode(String organizationCode) {
        this.organizationCode = organizationCode;
    }

    public int getScreenSysCompany() {
        return screenSysCompany;
    }

    public void setScreenSysCompany(int screenSysCompany) {
        this.screenSysCompany = screenSysCompany;
    }
}

==> mktcenter-service-threetree-1.0-20251210.080710-45-sources.jar: com/bizvane/mktcenterservice/models/vo/ProbabilityVO.java <==
package com.bizvane.mktcenterservice.models.vo;

/**
 * @Author: lijunwei
 * @Time: 2019/2/25 22:02
 */
public class ProbabilityVO {
    private Long mktActivityId;
    private String activityCode;
    private String memberCode;
    private Integer activityType;
    private Integer triesLimit;
    private Integer participateLimit;
    private Integer shareNum;
    private String organizationCode;
    //是否屏蔽总部 0不屏蔽,1屏蔽
    private int screenSysCompany;

    public Integer getParticipateLimit() {
        return participateLimit;
    }

    public void setParticipateLimit(Integer participateLimit) {
        this.participateLimit = participateLimit;
    }

    public Long getMktActivityId() {
        return mktActivityId;
    }

    public void setMktActivityId(Long mktActivityId) {
        this.mktActivityId = mktActivityId;
    }

    public String getActivityCode() {
        return activityCode;
    }

    public void setActivityCode(String activityCode) {
        this.activityCode = activityCode;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public Integer getTriesLimit() {
        return triesLimit;
    }

    public void setTriesLimit(Integer triesLimit) {
        this.triesLimit = triesLimit;
    }

    public Integer getActivityType() {
        return activityType;
    }

    public void setActivityType(Integer activityType) {
        this.activityType = activityType;
    }

    public Integer getShareNum() {
        return shareNum;
    }

    public void setShareNum(Integer shareNum) {
        this.shareNum = shareNum;
    }

    public String getOrganizationCode() {
        return organizationCode;
    }

    public void setOrganizationCode(String organizationCode) {
        this.organizationCode = organizationCode;
    }

    public int getScreenSysCompany() {
        return screenSysCompany;
    }

    public void setScreenSysCompany(int screenSysCompany) {
        this.screenSysCompany = screenSysCompany;
    }
}
